@@ -74,12 +74,24 @@ class Wordle(object):
         board = Image.new("RGB", board_size, self.bg_color)
 
         for i in range(self.rows):
+            word_temp = self.word_lower  # 临时变量
             for j in range(self.length):
                 letter = self.guessed_words[i][j] if len(self.guessed_words) > i else ""
                 if letter:
                     if letter == self.word_lower[j]:
                         color = self.correct_color
-                    elif letter in self.word_lower:
+
+                    elif (
+                        letter in word_temp
+                        and self.guessed_words[i][word_temp.find(letter)] != letter
+                    ):
+                        """
+                        一个字母的黄色和绿色数量与答案中的数量保持一致
+                        以输入apple，答案adapt为例
+                        结果为apple的第一个p是黄色，第二个p是灰色
+                        代表答案中只有一个p，且不在第二个位置
+                        """
+                        word_temp.replace(letter, "_", 1)
                         color = self.exist_color
                     else:
                         color = self.wrong_color
